pub struct StdSerialTransport<const ASCII: bool = false> { /* private fields */ }Expand description
A concrete implementation of Transport for Serial communication using serialport crate.
The const generic ASCII selects the framing mode at compile time:
false→ Modbus RTU (binary + CRC)true→ Modbus ASCII (:delimited + LRC)
Prefer the type aliases StdRtuTransport and StdAsciiTransport.
Implementations
Sourceimpl<const ASCII: bool> StdSerialTransport<ASCII>
impl<const ASCII: bool> StdSerialTransport<ASCII>
Sourcepub fn available_ports() -> Result<Vec<SerialPortInfo>, Error>
pub fn available_ports() -> Result<Vec<SerialPortInfo>, Error>
Returns a list of available serial ports on the system. This can be useful for allowing a user to select a port.