pub struct StdSerialTransport { /* private fields */ }Expand description
A concrete implementation of Transport for Serial communication using serialport crate.
Supports both RTU and ASCII modes.
Implementations
Sourceimpl StdSerialTransport
impl StdSerialTransport
Sourcepub fn new(mode: SerialMode) -> Self
pub fn new(mode: SerialMode) -> Self
Creates a new StdSerialTransport instance.
Sourcepub fn available_ports() -> Result<Vec<SerialPortInfo>, Error>
pub fn available_ports() -> Result<Vec<SerialPortInfo>, Error>
Returns a list of available serial ports on the system. This can be useful for allowing a user to select a port.